import gocept.testing.mtime
import os
import pkg_resources
import unittest


MAKEFILE_DIR = os.getcwd()


class TestMinifiedJSFiles(unittest.TestCase, gocept.testing.mtime.Newer):

    source_ext = '.js'
    target_ext = '.min.js'
    message = '\nRun `make` in %s to fix this.' % MAKEFILE_DIR
    delta = 7  # time delta for jenkins needs to be higher than default.

    def test_minified_js_files_are_younger_than_non_minified_ones(self):
        self.check_files(
            pkg_resources.resource_filename('ajja', 'resources/src'))
        self.check_files(
            pkg_resources.resource_filename('ajja', 'additional'))



import fanstatic
import js.classy
import js.jquery
import js.knockout

try:
    import js.bootstrap
    import js.jqueryui
except ImportError:
    HAS_CONTAINER_DEPENDENCIES = False
else:
    HAS_CONTAINER_DEPENDENCIES = True

library = fanstatic.Library('ajja', 'resources')
additionals = fanstatic.Library('ajja', 'additional')

handlebars = fanstatic.Resource(additionals, 'handlebars-v4.0.2.js')


ko_mapping = fanstatic.Resource(
    additionals, 'ko.mapping.js', minified='ko.mapping.min.js',
    depends=[js.knockout.knockout])

helpers = fanstatic.Resource(
    library, 'helpers.js', minified='helpers.min.js',
    depends=[js.jquery.jquery, ko_mapping])

templates = fanstatic.Resource(
    library, 'templates.js', minified='templates.min.js')

localization_de = fanstatic.Resource(
    library, 'localizations/de.js', minified='localizations/de.min.js')

localization_en = fanstatic.Resource(
    library, 'localizations/en.js', minified='localizations/en.min.js')

form = fanstatic.Resource(
    library, 'form.js', minified='form.min.js',
    depends=[
        helpers,
        js.classy.classy,
        handlebars,
        js.jquery.jquery,
        localization_de,
        localization_en,
        templates,
    ])

if HAS_CONTAINER_DEPENDENCIES is True:

    container_widget = fanstatic.Resource(
        library, 'collection.js', minified='collection.min.js',
        depends=[
            js.bootstrap.bootstrap_css,
            js.bootstrap.bootstrap_js,
            js.jquery.jquery,
            js.jqueryui.bootstrap,
            form,
        ])

    list_widget = container_widget  # backwards compatibility



# This should be only one line. If it must be multi-line, indent the second
# line onwards to keep the PKG-INFO file format intact.
"""Next generation forms in javascript"""

from setuptools import setup, find_packages
import glob
import os.path
import json
import sys


def read(path):
    if sys.version_info < (3,):
        f = open(path)
    else:
        f = open(path, encoding='UTF-8')
    text = f.read()
    f.close()
    return text


def project_path(*names):
    return os.path.join(os.path.dirname(__file__), *names)


version = json.loads(read(project_path(
    'src', 'ajja', 'resources', 'bower.json')))['version']


setup(
    name='ajja',
    version=version,

    install_requires=[
        'cssmin',
        'fanstatic>=1.0a2',
        'js.classy',
        'js.jquery',
        'js.knockout>=3.1.0',
        'setuptools',
    ],

    extras_require={
        'test': [
            'gocept.jasmine>=0.3',
            'gocept.jslint',
            'gocept.testing',
        ],
        'listwidget': [
            'js.bootstrap',
            'js.jqueryui',
        ],
    },

    entry_points={
        'console_scripts': [
            # 'binary-name = ajja.module:function'
        ],
        'fanstatic.libraries': [
            'ajja = ajja.resource:library',
        ],
    },

    author=('Sebastian Wehrmann <sw@gocept.com>, '
            'Maik Derstappen <md@derico.de>'),
    author_email='sw@gocept.com',
    license='MIT',
    url='https://github.com/gocept/ajja',

    keywords='form javascript jquery client',
    classifiers="""\
License :: OSI Approved :: MIT License
Programming Language :: Python
Programming Language :: Python :: 2
Programming Language :: Python :: 2.6
Programming Language :: Python :: 2.7
Programming Language :: Python :: 2 :: Only
"""[:-1].split('\n'),
    description=__doc__.strip(),
    long_description='\n\n'.join(open(project_path(name)).read() for name in (
        'README.txt',
        'CHANGES.txt',
    )),

    packages=find_packages('src'),
    package_dir={'': 'src'},
    include_package_data=True,
    data_files=[('', glob.glob(project_path('*.txt')))],
    zip_safe=False,
)
